pilas.tareas.Tarea

Package pilas :: Module tareas :: Class Tarea |
[hide private]
[frames] | no frames]

# Class Tarea

source code

    object --+
             |
            Tarea

Known Subclasses:
  - TareaCondicional

Instance Methods | [hide private]
__init__(self, planificador, time_out, dt, funcion, parametros, una_vez) Representa una tarea que se puede ejecutar dentro del planificador. | source code
ejecutar(self) Ejecuta la tarea. | source code
eliminar(self) Quita la tarea del planificador para que no se vuelva a ejecutar. | source code
terminar(self) Termina la tarea (alias de eliminar). | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, planificador, time_out, dt, funcion, parametros, una_vez) (Constructor) | source code
Representa una tarea que se puede ejecutar dentro del planificador. :param time_out: El tiempo absoluto para ejecutar la tarea. :param dt: La frecuencia de ejecución. :param funcion: La funcion a invocar. :param parametros: Una lista de argumentos para la funcion anterior. :param una_vez: Indica si la funcion se tiene que ejecutar una sola vez. Overrides: object.__init__